Code Reviews
============

Code reviews are a critical component of all OpenStack projects. Code reviews provide a
way to enforce a level of consistency across the project, and also allow for the careful
onboarding of contributions from new contributors.

Code Review Practices
---------------------
Networking-PowerVM follows the `code review guidelines <https://wiki.openstack.org/wiki/ReviewChecklist>`_ as
set forth for all OpenStack projects. It is expected that all reviewers are following the guidelines
set forth on that page.

